"use strict";

require("../mocha-config");
var $ = require('jquery');

var AddOverlayDialog = require('../../../main/js/gui/AddOverlayDialog');
var ServerConnector = require('../ServerConnector-mock');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../logger');

describe('AddOverlayDialog', function () {

  it('addOverlay', function () {
    var dialog;
    return ServerConnector.getProject().then(function (project) {
      dialog = createDialog(project);

      dialog.setFileContent("s1\n");
      assert.equal(0, logger.getWarnings().length);
      return dialog.addOverlay();
    });
  });

  /**
   *
   * @param {Project} project
   * @returns {AddOverlayDialog}
   */
  function createDialog(project) {
    return new AddOverlayDialog({
      element: testDiv,
      project: project,
      customMap: null,
      configuration: helper.getConfiguration(),
      serverConnector: ServerConnector
    });
  }

  describe('constructor', function () {
    it('hide consent checkbox for non google maps api project', function () {
      var dialog;
      return ServerConnector.getProject().then(function (project) {
        project.setMapCanvasType("OPEN_LAYERS");
        dialog = createDialog(project);
        assert.equal(0, $("[name='overlay-google-consent']", dialog.getElement()).length);
      });
    });
    it('hide consent checkbox for non google maps api project', function () {
      var dialog;
      return ServerConnector.getProject().then(function (project) {
        project.setMapCanvasType("GOOGLE_MAPS_API");
        dialog = createDialog(project);
        assert.ok($("[name='overlay-google-consent']", dialog.getElement()).length > 0);
      });
    });
  });

});
